************************************************************************************************************************************** 
************************Self-Assessed Health and Socio-Economic Status Using the GSOEP************************************************
***************************Project with Andrew Jones and Nigel Rice - 4 Jul 2008*************************************************** 
***************************"C: \Documents and Settings\Eigene Dateien\sah_ses\dofile_jrs0306.do"************************************** 
************************************************************************************************************************************** 


clear 
set trace off 
set more off 
set mem 500m 
set matsize 2200 
capture log close 



cd "C:\Documents and Settings\sschurer\My Documents\PhD Thesis Stefanie Schurer\SAH and SES Panel Methods\JAE Changes" 

log using createdataset, replace 

program drop _all 

use "C:\Documents and Settings\sschurer\My Documents\PhD Thesis Stefanie Schurer\SAH and SES Panel Methods\JAE Changes\secgen200906\secgen200906-long.dta", clear

set scheme s1manual 

/**********************************************Creation of the sample******************************************************************* 
*** Male and Female, ad between 18 and 64 T = 11 (1994-20045), n = ? *** 
*** Variables to be chose as Socio-economic status: yaome, education, use gross individual or household yaome, choose yaome to be*** 
*** the natural log to allow for the concave relationship between yaome and health. Find quotes Ettner 1996, Frijters et al. 2003, *** 
*** van Dorslaer and Koolman 2004, Contoyannis 2004. Education is the higherst educational attainment at the end of each sample     *** 
*** period. Choose the right reference category, Jones, Koolman and Rice chose 'no qualification'. Individual demographics 	      *** 
*** characteristics and sta of life: Marital status, ethnic origin, household size, number of children living in the household at *** 
*** different as. a is yaluded as fourth order polynominal, don't forget to divide a^2 = a^2/100, a^3/10000, a^4/1000000.* 
*** yalude a vector of wave dummies to account for aggregate health shocks, time-varying reporting changes, and any effects that a * 
*** doesn't capture *** 
***********************************************Sample Evolution************************************************************************ 
***Check: Men and Women at Wave 1 - 11, number of individuals, Dropouts, Rejoiners, Survival Rate in %, Raw Dropout rate, net drop***** 
***out rate, Dropout rates at wave t-1, exclude individual if still in school school7==1*********************************************** 
*************************************************************************************************************************************** 

******************************************************Generate Variables of Interest************************************* 
************************************************************************************************************************* 
*** Self-assessed health: sah==1 (very good), sah==2 (good) , sah==3 (satisfactory) , sah==4 (poor) , sah == (bad) ****** 
*************************************************************************************************************************/ 



#delimit ;

gen sah = p4650x if p4650x > 0 ;
label var sah "Self-assessed health" ;
tab sah, gen(sah) ;

gen sahvego = 0 ;
replace sahvego = 1 if sah1 == 1 ;
replace sahvego = . if sah1 == . ;
label var sahvego "Very good health" ;

gen sahgood = 0 ;
replace sahgood = 1 if sah2==1 ;
replace sahgood = . if sah2==. ;
label var sahgood "Good health" ;

gen sahsat  = 0 ;
replace sahsat = 1 if sah3 == 1 ;
replace sahsat = . if sah3 == . ;
label var sahsat "Satisfactors health" ;


gen sahpoor = 0 ;
replace sahpoor = 1 if sah4 == 1 ;
replace sahpoor = . if sah4 == . ;
label var sahpoor "Poor health" ;

gen sahbad  = 0 ;
replace sahbad = 1 if sah5 == 1 ; 
replace sahbad = . if sah5 == . ;
label var sahbad "Bad health" ;


gen sahinv = . ;
recode sahinv . = 1 if sahbad==1 ;
recode sahinv . = 2 if sahpoor==1 ;
recode sahinv . = 3 if sahsat==1 ;
recode sahinv . = 4 if sahgood==1 ;
recode sahinv . = 5 if sahvego==1 ;
label define sahinvlab 1 "bad sah", add ;
label define sahinvlab 2 "poor sah", add ;
label define sahinvlab 3 "satisfactory sah", add ; 
label define sahinvlab 4 "good sah", add ;
label define sahinvlab 5 "very good sah", add ; 

gen swhealth = p80x if p80x > -1 ; /*Generate satisfaction with health & recode, such that we have 7 categories*/
tab swhealth, gen(swh) ;
local i = 1 ;
while `i' < 12 { ;
local j = `i' - 1 ;
rename swh`i' swh`j' ;
local i = `i' + 1 ;
} ;
label var swhealth "Satisfaction with health" ;

gen wah = p520x if p520x > 0 ;
tab wah, gen(wah) ;
label var wah "Worry about health" ;

gen swh = . ;
replace swh = 1 if swhealth >= 0 & swhealth < 3 ;
replace swh = 2 if swhealth == 3|swhealth == 4 ;
replace swh = 3 if swhealth == 5|swhealth == 6 ;
replace swh = 4 if swhealth == 8|swhealth == 7;
replace swh = 5 if swhealth == 10|swhealth == 9  ; 

label var swh "Satisfaction with health (5 categories)" ;



/************************************************************************************************************************* 
******						Creation of RHS Variables     							*******
*************************************************************************************************************************/

tab sex if sex>0, gen(gender) ;
gen male = 0 ;
replace male = 1 if gender1 == 1 ;
label var male "Male" ; 

gen female = 0 ;
replace female = 1 if gender2 == 1 ; 
label var female "Female" ;





#delimit ;
gen yrsedu = . ;
replace yrsedu = 0 if p2292x == -2 ;
replace yrsedu =   p2292x if p2292x > 0 ;
label variable yrsedu "No. years of eduaction" ;

tab p2283x if p2283x > 0, gen(school) ; /*School Diploma received, generated - Create Dummya Variables*/

tab p2286x if p2286x > 0 , gen(voctype) ; /*Generate vocational training dummies: for those whao don't have uni degree*/

gen uni = p2285x ;

tab uni if uni > 0, gen(univ) ; /*Generate university dummies*/

tab p2284x if p2284x > 0, gen(vocation) ; /*Generate vocation dummies: For all individuals*/


tab p2287x if p2287x > 0, gen(schoolfor) ;


tab p2288x if p2288x > 0, gen(vocfor) ;


gen novocation = 0 ;

replace novocation = 1 if voctype1 == 1|vocfor1==1 ;

gen apprentice = 0 ;

replace apprentice = 1 if (vocation1 == 1 | vocation2 == 1 | voctype2 == 1|vocfor2==1) ; 

gen technocrat = 0 ;

replace technocrat = 1 if (vocation3 == 1 | vocation4 == 1 | vocation5 == 1|vocfor3==1) ;

gen othvocat = 0 ;

replace othvocat = 1 if vocation6 == 1|vocfor5==1 ;

gen nodegree = 0 ;

replace nodegree = 1 if school6 == 1 ;

gen othdegree=0 ;

replace othdegree=1 if school5==1 ;

*** Those who have no degree *** ;

gen secondary = 0 ;

replace secondary = 1 if school1 == 1|schoolfor1==1; 

replace secondary = 1 if nodegree==1 ; 

replace secondary=1 if othdegree==1 ;

*** Those who have Realschule as degree *** ;

gen intermed = 0 ; 

replace intermed = 1 if school2 == 1|schoolfor2==1  ;

replace intermed = 1 if secondary==1&apprentice==1 ;

*** Those who have Abitur and no university degree *** ;

gen upper = 0 ; 

replace upper = 1 if (school3 == 1 | school4 == 1|schoolfor3==1 ) ;

replace upper=1 if intermed==1&technocrat==1 ;

replace upper=1 if secondary==1&technocrat==1 ;

 

*** Those whao have a university degree no matter whaich secondary schooling they had *** ;

gen univers = 0 ; 

replace univers = 1 if voctype3 == 1 | univ1==1|univ2==1|univ3==1|univ4==1|univ5==1|vocfor4==1 ;


replace secondary = 1 if (intermed==1&novocation==1) ;

replace upper=0 if (upper==1&univers==1) ;

replace intermed=0 if (intermed==1&univers==1) ;

replace secondary=0 if (secondary==1&univers==1) ;

replace intermed=0 if (intermed==1&upper==1) ;

replace secondary=0 if (secondary==1&upper==1) ;

replace secondary =0 if (secondary==1&intermed==1) ;


gen all  = secondary+ intermed+ upper+ univers ;

replace secondary = 1 if novocation == 1 & all ==0 ;

drop novocation-othdegree ;
drop school1- vocfor5 all ;

#delimit cr

gen education = 0
replace education = 1 if secondary == 1
replace education = 2 if intermed ==1
replace education = 3 if upper ==1
replace education = 4 if univers==1

label define edulab 1 "9 to 10 Yrs school" 2 "10 Yrs school + Training" 3 "13 Yrs school + Training" 4 "University"
label values education edulab 
label var secondary "Basic schooling (9 years)" 
label var intermed "Basic schooling plus vocation" 
label var upper "12 years schooling plus vocation" 
label var uni "University degree" 

#delimit ;

tab p2291x if p2291x > 0, gen(marital) ; /*Generate marital status variables*/

gen married = 0 ;
replace married = 1 if marital1 == 1 ;
replace married = . if marital1 == .  ;
label var married "Married" ;

gen single = 0 ;
replace single = 1 if marital3 == 1 ; 
replace single = . if marital3 == . ;
label var single "Single, never married" ;


gen separate = 0 ; /*yaludes all individuals whao are either not living with partner, divorced or widowed*/
replace separate = 1 if (marital4 == 1 | marital5 == 1 | marital2==1 | marital6 == 1 ) ;
replace separate = . if (marital4 == . | marital5 == . | marital2==1 | marital6 == 1) ;
label var separate "Divorced, separated, or widowed" ;


gen a1630 = 0 ;
replace a1630 = 1 if age<31&age>15 ;
label var a1630 "Age-group 16 to 30" ;

gen a3140 = 0 ;
replace a3140 = 1 if age<41 & age > 30 ;
label var a3140 "Age-group 31 to 40" ;


gen a4150 = 0 ;
replace a4150 = 1 if age<51 & age > 40 ;
label var a4150 "Age-group 41 to 50" ;


gen a5160 = 0 ;
replace a5160 = 1 if age<61 & age>50 ;
label var a5160 "Age-group 51 to 60" ;


gen a6170 = 0 ;
replace a6170 = 1 if age<71 & age>60 ;
label var a6170 "Age-group 61 to 70" ;


gen a71 = 0 ;
replace a71=1 if age>70 ;
label var a71 "Age-group 71 and older" ;




/* gen oweight=1+(p3468x-p3469x-1+p3521x)*0.5+p3520x*0.3 ; */ /* OECD Equivalence scale to weigh household yaome */ 
gen rweight=sqrt(p3468x) ; /* Approximation, Sachverstndigenrat */
/* gen equivya1 = h4612x/oweight ; */ 


*** Monthly net adjusted income ;

gen minc = h4613x if h4613x > = 0 ;

replace minc = . if h4613x==-3 ;
label variable minc "Monthly income (HH)" ;


gen equivya1 = h4612x/rweight  ;
gen lequinc1 = ln(equivya1) ;
label var lequinc1 "Log of net household equivalent income" ; 

 
rename p3468x hhsize ; /*Number of persons in household*/
label var hhsize "Number of person in hh" ;

rename p3469x chilhh ; /*Number of children in hh*/
label var chilhh "Number of children in hh" ;


gen unemp = 0 ;
replace unemp = 1 if p171x == 1  ;
replace unemp = . if p171x==-1|p171x==-3 ;
label var unemp "Registered unemployed" ;

label define unemplab 1 "Unemployed (reg.)" 0 "Not unemployed (reg.)", modify  ;
label values unemp unemplab  ;

gen hoursa = p2294x if p2294x >=0 ;
replace hoursa = 0 if p2294x == - 2 ;
replace hoursa = . if p2294x == - 1 ;
 




gen inactive3=. ;
replace inactive3 = 1 if (hoursa >=0 & hoursa<=15) ;
replace inactive3 = 0 if hoursa > 15 ;

label define inactive3lab 1 "Inactive" 0 "Working", modify  ;
label values inactive3 inactive3lab ;

gen inactively = 0 ; 

replace inactively = 1 if p498x == 2 ;
replace inactively = . if  p498x == -1|  p498x == -3 ;

tsset persnr year ;
gen inactive2 = F.inactively ;

label define inactive2lab 1 "Inactive" 0 "Working", modify  ;
label values inactive2 inactive2lab ;


xtile hhyao5 = lequinc1, n(5);

gen lyao1 = 0 ;
replace lyao1 = 1 if hhyao5 ==1 ;
label var lyao1 "Lowest 20% income earners" ; 

gen lyao2 = 0 ;
replace lyao2 = 1 if hhyao5==2 ;
label var lyao2 "Lowest 40% income earners" ; 

gen lyao3 = 0 ;
replace lyao3 = 1 if hhyao5==3 ;
label var lyao3 "Lowest 60% income earners" ; 

gen lyao4 = 0 ;
replace lyao4 = 1 if hhyao5==4 ;
label var lyao4 "Highest 40% income earners" ; 

gen lyao5 = 0 ;
replace lyao5 = 1 if hhyao5==5 ;
label var lyao5 "Highest 20% income earners" ; 

gen workhrs = p2294x  ; /*Generate annual workhours of an individual*/
replace workhrs = 0 if workhrs == -2 ;
replace workhrs = . if workhrs == -1 ;
replace workhrs = . if workhrs == -3 ;
label var workhrs "Annual work hours" ;


gen overtime = p2296x ;
replace overtime = 0 if overtime == -2 ;
replace overtime = . if overtime == -3 ;
replace overtime = . if overtime == -1 ;
label var overtime "Hours worked overtime" ;

tab h3111x if  h3111x > = 0, gen(state) ;
rename state1 berlinw ;
label var berlinw "Berlin West" ;
rename state2 schlhol ;
label var schlhol "Schleswig-Holstein" ;
rename state3 hamburg ;
label var hamburg "Hamburg" ;

rename state4 lowsax ;
label var lowsax "Lower-Saxony" ;

rename state5 bremen ;
label var bremen "Bremen" ;

rename state6 nrw ;
label var nrw "North Rhine Westphalia" ;

rename state7 hessia ; 
label var hessia "Hessia" ;

rename state8 rhine ;
label var rhine "Rhineland" ;

rename state9 wurttem ; 
label var wurttem "Wuerttemberg" ;

rename state10 bavaria ;
label var bavaria "Bavaria" ;

rename state11 berline  ;
label var berline "Berlin East" ;

rename state12 mecpom ;
label var mecpom "Mecklaneburg-Vorpommern" ;

rename state13 branden ;
label var branden "Brandenburg" ;

rename state14 saxanh ;
label var saxanh "Sachsen-Anhalt" ;

rename state15 thuringa ;
label var thuringa "Thuringia" ;
 
rename state16 saxony ;
label var saxony "Saxony" ;


/*Generate year dummies*/

tab year, gen(y) ;

local i = 1 ;
local j = 1984 ;
while `i' < 23 { ;
rename y`i' y`j' ;
label var y`j' "Year `j'" ;
local i = `i' + 1 ;
local j = `j' + 1 ;
} ;


/*** Generate Interaction Terms with yaome ***/

/*** a groups ***/

drop if lequinc1 == . ;
gen income = exp(lequinc1) ;
label var income "Net household equivalent income" ;
 
local listage "1630 3140 4150 5160 6170 71" ;


foreach var of local listage { ;

gen ya`var' =  lequinc1*a`var'  ;
replace ya`var' = . if lequinc1 == . ;  

gen y2a`var' =  income*a`var' ;
replace y2a`var' = . if lequinc1 == . ;  

label var ya`var' "Income age-group `var'" ; 
label var y2a`var' "Income age-group `var'" ; 
} ;


/* Number of years of last employment if one is unemployed or out of the labour force */


replace yearlast = year if yearlast == -2 ;
replace yearlast = . if yearlast == -1 ;
gen demploy = year - yearlast ;
drop if demploy < 0 ;
label var demploy "Years passed since last employment" ;


/*Work disability*/
drop if p499x == -1 ;
drop if p499x == -3 ;
gen wdisable = 0 ;
replace wdisable = 1 if p499x == 1;
label var wdisable "Work disability" ;

sort persnr year ;
by persnr: gen n = _n ;
by persnr: gen swhn1=swh if n==1 ;
label var swhn1 "SWH in first period" ;



#delimit ;
gen yrsip =  ((letztbef- erstbefr) + 1) ;
label var yrsip "Years in panel" ;

#delimit ;
keep persnr year hhnr sah sahvego sahgood sahsat sahpoor sahbad 
sahinv swh wah male female yrsedu secondary intermed upper uni married 
separate single hhsize age a1630 a3140 a4150 a5160 a6170 a71
lequinc1  minc hoursa  inactive3 inactive2 workhrs overtime 
hhsize chilhh lyao1-lyao5 unemp workhrs berlinw-saxony 
west east immig ysm sex gebjahr eintritt austritt todjahr 
psample germborn netto phrf y1984-y2005  
ya1630 ya3140 ya4150 ya5160 ya6170 ya71 
y2a1630 y2a3140 y2a4150 y2a5160 y2a6170 y2a71 
swhn1 swhealth wdisable demploy income yrsip  ;


/*keep persnr year sahinv east secondary intermed upper uni 
married separate single hhsize unemp 
ya1630 ya3140 ya4150 ya5160 ya6170 ya71
y1994-y2005 ; */


iis persnr ;
tis year ;
sum persnr ;  
xtdes ;

save "GSOEP (1984-2005) Workdata Jones and Schurer", replace ;

log close ;
