clear 
set trace off 
set more off 
set mem 500m 
set matsize 2200 

capture log close 

cd "C:\Documents and Settings\sschurer\My Documents\PhD Thesis Stefanie Schurer\SAH and SES Panel Methods\JAE Changes" 

log using "Marginal effects for ordred logit male sample", replace 


program drop _all 

#delimit ;
use "GSOEP (1984-2005) Workdata Jones and Schurer", clear ;

keep if male == 1 ;




set scheme s1manual ;

recode swh 1=0 2=1 3=2 4=3 5=4  ;


**************************************************************************** ;
*** Define variable lists for the estimations: indepvars1           	 *** ;
*** Define variable lists for marginal effects: convars1, convars2	 *** ;
**************************************************************************** ;

local indepvars1 "east a3140 a4150 a5160  
a6170 a71 ya1630 ya3140 ya4150 ya5160 ya6170 ya71 
yrsedu unemp overtime wdisable separate single hhsize 
y1984 y1985 y1986 y1987 y1988 y1989 y1990 y1991 y1992 y1993 
y1994 y1995 y1996 y1997 y1998 y1999 
y2000 y2001 y2003 y2004 y2005" ;



local convars1 "ya1630 ya3140 ya4150 ya5160 ya6170 ya71" ;

local agroups "a1630 a3140 a4150 a5160 a6170 a71" ;

local convars2 "ya1630 ya3140 ya4150 ya5160 ya6170 ya71 
mya1630 mya3140 mya4150 mya5160 mya6170 mya71" ;

	

program define margeffdum1  ;
		
        	version 10.0 ;
		args pred beta    ;
	  	nlcom (d1`beta': (exp(`pred')/(1+exp(`pred'))^2)*_b[swh:`beta']) ;
		
end ;


program define margeffdum2  ;
		
        	version 10.0 ;
		args pred beta    ;
	  	nlcom (d2`beta': (exp(`pred')/(1+exp(`pred'))^2)*_b[swh:`beta']) ;
		
end ;

program define margeffdum3  ;
		
        	version 10.0 ;
		args pred beta    ;
	  	nlcom (d3`beta': (exp(`pred')/(1+exp(`pred'))^2)*_b[swh:`beta']) ;
		
end ;

program define margeffdum4  ;
		
        	version 10.0 ;
		args pred beta    ;
	  	nlcom (d4`beta': (exp(`pred')/(1+exp(`pred'))^2)*_b[swh:`beta']) ;
		
end ;




********************************************************************** ;
**** Programs to calculate marginal effects by hand               **** ;
********************************************************************** ;

local i = 1 ;

forvalues s =1(1)4 { ;
mat meff`s'=J(6,1,0) ;
mat seeff`s'=J(6,1,0) ;
} ;

ologit swh `indepvars1', cluster(persnr) ;

foreach var1 of varlist `agroups' { ;

forvalues s = 1(1)4 { ;

predict xb`s'`var1' if (e(sample) == 1 & `var1' == 1), xb ;

summ xb`s'`var1' ;
local mxb`var1'`s' = (_b[cut`s': _cons] - r(mean))  ;


for var y`var1' :
margeffdum`s' `mxb`var1'`s'' X _b[swh:X] ;

mat c = r(b) ;
mat v = r(V) ;

mat meff`s'[`i',1]  = c[1,1] ;
mat seeff`s'[`i',1]  = sqrt(v[1,1]) ;

drop xb`s'`var1' ;
local s = `s' + 1 ;
} ;

local i = `i' + 1 ;
} ;


	

**************************************************************************** ;
*** Program to graphs the predicted probabilities of answering outcome 1 *** ;
*** outcome 3, outcome 5, etc. over household income 				 *** ;
**************************************************************************** ;

foreach var0 of varlist `agroups' { ; 
foreach var of varlist `indepvars1' { ;
sum `var' if (e(sample) & `var0' == 1) ;
local m`var'`var0' = r(mean) ;
} ;
} ;

mat prob_a1630  = J(26,1,0) ;
mat prob_a3140 = J(26,1,0) ;
mat prob_a4150 = J(26,1,0) ;
mat prob_a5160 = J(26,1,0) ;
mat prob_a6170 = J(26,1,0) ;
mat prob_a71 = J(26,1,0) ;

mat inc = J(26,1,0) ;
local j = 500 ;
local i = 1 ;
while `j' < 5501 { ;
	mat inc[`i',1] = (`j') ;
	local j = `j' + 200 ;
	local i = `i' + 1 ;
} ;


************************ ;
*** Outcome 1 and 5: *** ;
************************ ;

local j = 1 ;
local s = 1 ;
local t = 1 ;

while `s' < 5 { ;

forvalues i = 500(200)5500 { ; 

local xb`s'`j' _b[cut`s':_cons] - (_b[east]*`measta1630' + _b[a3140]*0 + _b[a4150]*0 + _b[a5160]*0 
+ _b[a6170]*0 + _b[a71]*0 + _b[ya1630]*ln(`i') + _b[ya3140]*0 + _b[ya4150]*0 + _b[ya5160]*0 + _b[ya6170]*0 + _b[ya71]*0 
+ _b[yrsedu]*`myrsedua1630' + _b[unemp]*`munempa1630' + _b[overtime]*`movertimea1630' 
+ _b[wdisable]*`mwdisablea1630' + _b[separate]*`mseparatea1630' + _b[single]*`msinglea1630' 
+ _b[hhsize]*`mhhsizea1630' + _b[y1984]*`my1984a1630' + _b[y1985]*`my1985a1630' 
+ _b[y1986]*`my1986a1630' + _b[y1987]*`my1987a1630' + _b[y1988]*`my1988a1630' 
+ _b[y1989]*`my1989a1630' + _b[y1990]*`my1990a1630' + _b[y1991]*`my1991a1630' 
+ _b[y1992]*`my1992a1630' + _b[y1993]*`my1993a1630' + _b[y1994]*`my1994a1630' 
+ _b[y1995]*`my1995a1630' + _b[y1996]*`my1996a1630' + _b[y1997]*`my1997a1630' 
+ _b[y1998]*`my1998a1630' + _b[y1999]*`my1999a1630' + _b[y2000]*`my2000a1630' 
+ _b[y2001]*`my2001a1630' + _b[y2003]*`my2003a1630' 
+ _b[y2004]*`my2004a1630' + _b[y2005]*`my2005a1630' ) ;

mat prob_a1630[`j',1] = 1 - (exp(`xb`s'`j'')/(1+exp(`xb`s'`j''))) ;

local xb`s'`j' _b[cut`s':_cons] - (_b[east]*`measta3140' + _b[a3140]*1 + _b[a4150]*0 + _b[a5160]*0 +  
_b[a6170]*0 + _b[a71]*0 + _b[ya1630]*0 + _b[ya3140]* ln(`i') + _b[ya4150]*0 + _b[ya5160]*0 + _b[ya6170]*0 + _b[ya71]*0 + 
_b[yrsedu]*`myrsedua3140' + _b[unemp]*`munempa3140' + _b[overtime]*`movertimea3140' + _b[wdisable]*`mwdisablea3140' + 
_b[separate]*`mseparatea3140' + _b[single]*`msinglea3140' + _b[hhsize]*`mhhsizea3140' + 
_b[y1984]*`my1984a3140' + _b[y1985]*`my1985a3140' + _b[y1986]*`my1986a3140' + 
_b[y1987]*`my1987a3140' + _b[y1988]*`my1988a3140' + _b[y1989]*`my1989a3140' + _b[y1990]*`my1990a3140' + 
_b[y1991]*`my1991a3140' + _b[y1992]*`my1992a3140' + _b[y1993]*`my1993a3140' + 
_b[y1994]*`my1994a3140' + _b[y1995]*`my1995a3140' + _b[y1996]*`my1996a3140' + _b[y1997]*`my1997a3140' +
_b[y1998]*`my1998a3140' + _b[y1999]*`my1999a3140' + 
_b[y2000]*`my2000a3140' + _b[y2001]*`my2001a3140' + _b[y2003]*`my2003a3140' 
+ _b[y2004]*`my2004a3140' + _b[y2005]*`my2005a3140' ) ;

  
mat prob_a3140 [`j',1] = 1 - (exp(`xb`s'`j'')/(1+exp(`xb`s'`j''))) ;


local xb`s'`j' _b[cut`s':_cons]-(_b[east]*`measta4150' + _b[a3140]*0 + _b[a4150]*1 + _b[a5160]*0 +  
_b[a6170]*0 + _b[a71]*0 + _b[ya1630]*0 + _b[ya3140]*0 + _b[ya4150]*ln(`i') + _b[ya5160]*0 + _b[ya6170]*0 + _b[ya71]*0 + 
_b[yrsedu]*`myrsedua4150' + _b[unemp]*`munempa4150' + _b[overtime]*`movertimea4150' + _b[wdisable]*`mwdisablea4150' + 
_b[separate]*`mseparatea4150' + _b[single]*`msinglea4150' + _b[hhsize]*`mhhsizea4150' + 
_b[y1984]*`my1984a4150' + _b[y1985]*`my1985a4150' + _b[y1986]*`my1986a4150' + 
_b[y1987]*`my1987a4150' + _b[y1988]*`my1988a4150' + _b[y1989]*`my1989a4150' + _b[y1990]*`my1990a4150' + 
_b[y1991]*`my1991a4150' + _b[y1992]*`my1992a4150' + _b[y1993]*`my1993a4150' + 
_b[y1994]*`my1994a4150' + _b[y1995]*`my1995a4150' + _b[y1996]*`my1996a4150' + _b[y1997]*`my1997a4150' +
_b[y1998]*`my1998a4150' + _b[y1999]*`my1999a4150' + 
_b[y2000]*`my2000a4150' + _b[y2001]*`my2001a4150' + _b[y2003]*`my2003a4150' 
+ _b[y2004]*`my2004a4150' + _b[y2005]*`my2005a4150' ) ;


mat prob_a4150[`j',1] = 1 - (exp(`xb`s'`j'')/(1+exp(`xb`s'`j''))) ;

local xb`s'`j' _b[cut`s':_cons]-(_b[east]*`measta5160' + _b[a3140]*0 + _b[a4150]*0 + _b[a5160]*1 +  
_b[a6170]*0 + _b[a71]*0 + _b[ya1630]*0 + _b[ya3140]*0 + _b[ya4150]*0 + _b[ya5160]*ln(`i') + _b[ya6170]*0 + _b[ya71]*0 + 
_b[yrsedu]*`myrsedua5160' + _b[unemp]*`munempa5160' + _b[overtime]*`movertimea5160' + _b[wdisable]*`mwdisablea5160' + 
_b[separate]*`mseparatea5160' + _b[single]*`msinglea5160' + _b[hhsize]*`mhhsizea5160' + 
_b[y1984]*`my1984a5160' + _b[y1985]*`my1985a5160' + _b[y1986]*`my1986a5160' + 
_b[y1987]*`my1987a5160' + _b[y1988]*`my1988a5160' + _b[y1989]*`my1989a5160' + _b[y1990]*`my1990a5160' + 
_b[y1991]*`my1991a5160' + _b[y1992]*`my1992a5160' + _b[y1993]*`my1993a5160' + 
_b[y1994]*`my1994a5160' + _b[y1995]*`my1995a5160' + _b[y1996]*`my1996a5160' + _b[y1997]*`my1997a5160' +
_b[y1998]*`my1998a5160' + _b[y1999]*`my1999a5160' + 
_b[y2000]*`my2000a5160' + _b[y2001]*`my2001a5160' + _b[y2003]*`my2003a5160' 
+ _b[y2004]*`my2004a5160' + _b[y2005]*`my2005a5160' ) ;

mat prob_a5160[`j',1] = 1 - (exp(`xb`s'`j'')/(1+exp(`xb`s'`j''))) ;

local xb`s'`j' _b[cut`s':_cons]-(_b[east]*`measta6170' + _b[a3140]*0 + _b[a4150]*0 + _b[a5160]*0 +  
_b[a6170]*1 + _b[a71]*0 + _b[ya1630]*0 + _b[ya3140]*0 + _b[ya4150]*0 + _b[ya5160]*0 + _b[ya6170]*ln(`i') + _b[ya71]*0 + 
_b[yrsedu]*`myrsedua6170' + _b[unemp]*`munempa6170' + _b[overtime]*`movertimea6170' + _b[wdisable]*`mwdisablea6170' + 
_b[separate]*`mseparatea6170' + _b[single]*`msinglea6170' + _b[hhsize]*`mhhsizea6170' + 
_b[y1984]*`my1984a6170' + _b[y1985]*`my1985a6170' + _b[y1986]*`my1986a6170' + 
_b[y1987]*`my1987a6170' + _b[y1988]*`my1988a6170' + _b[y1989]*`my1989a6170' + _b[y1990]*`my1990a6170' + 
_b[y1991]*`my1991a6170' + _b[y1992]*`my1992a6170' + _b[y1993]*`my1993a6170' + 
_b[y1994]*`my1994a6170' + _b[y1995]*`my1995a6170' + _b[y1996]*`my1996a6170' + _b[y1997]*`my1997a6170' +
_b[y1998]*`my1998a6170' + _b[y1999]*`my1999a6170' + 
_b[y2000]*`my2000a6170' + _b[y2001]*`my2001a6170' + _b[y2003]*`my2003a6170' + _b[y2004]*`my2004a6170' 
+ _b[y2005]*`my2005a6170' ) ;

mat prob_a6170[`j',1] = 1 - (exp(`xb`s'`j'')/(1+exp(`xb`s'`j''))) ;

local xb`s'`j' _b[cut`s':_cons]-(_b[east]*`measta71' + _b[a3140]*0 + _b[a4150]*0 + _b[a5160]*0 +  
_b[a6170]*0 + _b[a71]*1 + _b[ya1630]*0 + _b[ya3140]*0 + _b[ya4150]*0 + _b[ya5160]*0 + _b[ya6170]*0 + _b[ya71]*ln(`i') + 
_b[yrsedu]*`myrsedua71' + _b[unemp]*`munempa71' + _b[overtime]*`movertimea71' +_b[wdisable]*`mwdisablea71' + 
_b[separate]*`mseparatea71' + _b[single]*`msinglea71' + _b[hhsize]*`mhhsizea71' + 
_b[y1984]*`my1984a71' + _b[y1985]*`my1985a71' + _b[y1986]*`my1986a71' + 
_b[y1987]*`my1987a71' + _b[y1988]*`my1988a71' + _b[y1989]*`my1989a71' + _b[y1990]*`my1990a71' + 
_b[y1991]*`my1991a71' + _b[y1992]*`my1992a71' + _b[y1993]*`my1993a71' + 
_b[y1994]*`my1994a71' + _b[y1995]*`my1995a71' + _b[y1996]*`my1996a71' + _b[y1997]*`my1997a71' +
_b[y1998]*`my1998a71' + _b[y1999]*`my1999a71' + 
_b[y2000]*`my2000a71' + _b[y2001]*`my2001a71' + _b[y2003]*`my2003a71' + _b[y2004]*`my2004a71' + _b[y2005]*`my2005a71') ;

mat prob_a71[`j',1] = 1 - (exp(`xb`s'`j'')/(1+exp(`xb`s'`j''))) ;



local j = `j' + 1 ;	
} ;

svmat inc, name(income) ; 
svmat prob_a1630 , name(proba1630) ;
svmat prob_a3140, name(proba3140) ;
svmat prob_a4150, name(proba4150) ;
svmat prob_a5160, name(proba5160) ;
svmat prob_a6170, name(proba6170) ;
svmat prob_a71, name(proba71) ;


if `s' < 4 { ;
line proba16301 income1, lwidth(medthick) lcolor(red) pstyle(p2)  || 
line proba31401 income1, lwidth(medthick) lcolor(blue) pstyle(p3)  || 
line proba41501 income1, lwidth(medthick) lcolor(lime) pstyle(p4) || 
line proba51601 income1, lwidth(medthick) lcolor(pink) pstyle(p5) ||  
line proba61701 income1, lwidth(medthick) lcolor(gold) pstyle(p6) ||  
line proba711 income1, lwidth(medthick) lcolor(dkgreen) pstyle(p8) ||, 
plotregion(style(none))
ytitle("Pr(SWH > `s')") xtitle("Monthly Income (in Euro)") 
ylabel(,grid)
xlabel(500(500)5500) 
legend(cols(3) region(lstyle(none)) 
label(1 "16 to 30") label(2 "31 to 40") label(3 "41 to 50") 
label(4 "51 to 60") label(5 "61 to 70") label(6 "71 and older")) ;

graph export "SWH_OLOGIT_pr`s'_m.eps", as(eps) preview(on) replace ;

} ;


else { ;
line proba16301 income1, lwidth(medthick) lcolor(red) pstyle(p2)  || 
line proba31401 income1, lwidth(medthick) lcolor(blue) pstyle(p3)  || 
line proba41501 income1, lwidth(medthick) lcolor(lime) pstyle(p4) || 
line proba51601 income1, lwidth(medthick) lcolor(pink) pstyle(p5) ||  
line proba61701 income1, lwidth(medthick) lcolor(gold) pstyle(p6) ||  
line proba711 income1, lwidth(medthick) lcolor(dkgreen) pstyle(p8) ||, 
plotregion(style(none))
ytitle("Pr(SWH = 5)") xtitle("Monthly Income (in Euro)") 
ylabel(,grid)
xlabel(500(500)5500) 
legend(cols(3) region(lstyle(none)) 
label(1 "16 to 30") label(2 "31 to 40") label(3 "41 to 50") 
label(4 "51 to 60") label(5 "61 to 70") label(6 "71 and older")) ;

graph export "SWH_OLOGIT_pr`s'_m.eps", as(eps) preview(on) replace ;

} ;


drop income1 proba16301 proba31401 proba41501 proba51601 proba61701 proba711 ;


mat min`s' = J(6,1,0) ;
mat max`s' = J(6,1,0) ;

local i = 1 ;
while `i' < 7 {;
mat min`s'[`i',1] = meff`s'[`i',1] - 1.96*seeff`s'[`i',1] ;
mat max`s'[`i',1] = meff`s'[`i',1] + 1.96*seeff`s'[`i',1] ;

local i = `i' + 1 ;
} ;


svmat double meff`s', name(me`s') ;
svmat double min`s', name(min`s') ;
svmat double max`s', name(max`s') ;


local s = `s' + 1 ;
local j = 1 ;
} ;

keep me11 me21 me31 me41 min11 min21 min31 min41 max11 max21 max31 max41 ;

drop if me11==. ;
drop if me21==. ;
drop if me31==. ;
drop if me41==. ;

save "mepol_m.dta", replace ;

keep me11 min11 max11 ;
save "mepol1_m.dta", replace ;

use "mepol_m.dta", clear ;
keep me21 min21 max21 ;
save "mepol2_m.dta", replace ;

use "mepol_m.dta", clear ;
keep me31 min31 max31 ;
save "mepol3_m.dta", replace ;

use "mepol_m.dta", clear ;
keep me41 min41 max41 ;
save "mepol4_m.dta", replace ;
 

log close ;

#delimit cr

clear 
set trace off 
set more off 
set mem 500m 
set matsize 2200 

capture log close 

cd "C:\Documents and Settings\sschurer\My Documents\PhD Thesis Stefanie Schurer\SAH and SES Panel Methods\JAE Changes" 

log using "Marginal effects for ordred logit female sample", replace 


program drop _all 

#delimit ;
use "GSOEP (1984-2005) Workdata JAE", clear ;

keep if female == 1 ;




set scheme s1manual ;


**************************************************************************** ;
*** Define variable lists for the estimations: indepvars1, indepvars2	 *** ;
*** Define variable lists for marginal effects: convars1, convars2	 *** ;
**************************************************************************** ;

local indepvars1 "east a3140 a4150 a5160  
a6170 a71 ya1630 ya3140 ya4150 ya5160 ya6170 ya71 
yrsedu unemp overtime wdisable separate single hhsize 
y1984 y1985 y1986 y1987 y1988 y1989 y1990 y1991 y1992 y1993 
y1994 y1995 y1996 y1997 y1998 y1999 
y2000 y2001 y2003 y2004 y2005" ;


local convars1 "ya1630 ya3140 ya4150 ya5160 ya6170 ya71" ;

local agroups "a1630 a3140 a4150 a5160 a6170 a71" ;

local convars2 "ya1630 ya3140 ya4150 ya5160 ya6170 ya71 
mya1630 mya3140 mya4150 mya5160 mya6170 mya71" ;

	

program define margeffdum1  ;
		
        	version 10.0 ;
		args pred beta    ;
	  	nlcom (d1`beta': (exp(`pred')/(1+exp(`pred'))^2)*_b[swh:`beta']) ;
		
end ;


program define margeffdum2  ;
		
        	version 10.0 ;
		args pred beta    ;
	  	nlcom (d2`beta': (exp(`pred')/(1+exp(`pred'))^2)*_b[swh:`beta']) ;
		
end ;

program define margeffdum3  ;
		
        	version 10.0 ;
		args pred beta    ;
	  	nlcom (d3`beta': (exp(`pred')/(1+exp(`pred'))^2)*_b[swh:`beta']) ;
		
end ;

program define margeffdum4  ;
		
        	version 10.0 ;
		args pred beta    ;
	  	nlcom (d4`beta': (exp(`pred')/(1+exp(`pred'))^2)*_b[swh:`beta']) ;
		
end ;




********************************************************************** ;
**** Programs to calculate marginal effects by hand               **** ;
********************************************************************** ;

local i = 1 ;

forvalues s =1(1)4 { ;
mat meff`s'=J(6,1,0) ;
mat seeff`s'=J(6,1,0) ;
} ;

ologit swh `indepvars1' if year, cluster(persnr) ;

foreach var1 of varlist `agroups' { ;

forvalues s = 1(1)4 { ;

predict xb`s'`var1' if (e(sample) == 1 & `var1' == 1), xb ;

summ xb`s'`var1' ;
local mxb`var1'`s' = (_b[cut`s': _cons] - r(mean))  ;


for var y`var1' :
margeffdum`s' `mxb`var1'`s'' X _b[swh:X] ;

mat c = r(b) ;
mat v = r(V) ;

mat meff`s'[`i',1]  = c[1,1] ;
mat seeff`s'[`i',1]  = sqrt(v[1,1]) ;

drop xb`s'`var1' ;
local s = `s' + 1 ;
} ;
local i = `i' + 1 ;
} ;
	

**************************************************************************** ;
*** Program to graphs the predicted probabilities of answering outcome 1 *** ;
*** outcome 3, outcome 5, etc. over household income 				 *** ;
**************************************************************************** ;

foreach var0 of varlist `agroups' { ; 
foreach var of varlist `indepvars1' { ;
sum `var' if (e(sample) & `var0' == 1) ;
local m`var'`var0' = r(mean) ;
} ;
} ;

mat prob_a1630  = J(26,1,0) ;
mat prob_a3140 = J(26,1,0) ;
mat prob_a4150 = J(26,1,0) ;
mat prob_a5160 = J(26,1,0) ;
mat prob_a6170 = J(26,1,0) ;
mat prob_a71 = J(26,1,0) ;

mat inc = J(26,1,0) ;
local j = 500 ;
local i = 1 ;
while `j' < 5501 { ;
	mat inc[`i',1] = (`j') ;
	local j = `j' + 200 ;
	local i = `i' + 1 ;
} ;


************************ ;
*** Outcome 1 and 5: *** ;
************************ ;

local j = 1 ;
local s = 1 ;
local t = 1 ;

while `s' < 5 { ;

forvalues i = 500(200)5500 { ; 

local xb`s'`j' _b[cut`s':_cons] - (_b[east]*`measta1630' + _b[a3140]*0 + _b[a4150]*0 + _b[a5160]*0 
+ _b[a6170]*0 + _b[a71]*0 + _b[ya1630]*ln(`i') + _b[ya3140]*0 + _b[ya4150]*0 + _b[ya5160]*0 + _b[ya6170]*0 + _b[ya71]*0 
+ _b[yrsedu]*`myrsedua1630' + _b[unemp]*`munempa1630' + _b[overtime]*`movertimea1630' 
+ _b[wdisable]*`mwdisablea1630' + _b[separate]*`mseparatea1630' + _b[single]*`msinglea1630' 
+ _b[hhsize]*`mhhsizea1630' + _b[y1984]*`my1984a1630' + _b[y1985]*`my1985a1630' 
+ _b[y1986]*`my1986a1630' + _b[y1987]*`my1987a1630' + _b[y1988]*`my1988a1630' 
+ _b[y1989]*`my1989a1630' + _b[y1990]*`my1990a1630' + _b[y1991]*`my1991a1630' 
+ _b[y1992]*`my1992a1630' + _b[y1993]*`my1993a1630' + _b[y1994]*`my1994a1630' 
+ _b[y1995]*`my1995a1630' + _b[y1996]*`my1996a1630' + _b[y1997]*`my1997a1630' 
+ _b[y1998]*`my1998a1630' + _b[y1999]*`my1999a1630' + _b[y2000]*`my2000a1630' 
+ _b[y2001]*`my2001a1630' + _b[y2003]*`my2003a1630' 
+ _b[y2004]*`my2004a1630' + _b[y2005]*`my2005a1630' ) ;

mat prob_a1630[`j',1] = 1 - (exp(`xb`s'`j'')/(1+exp(`xb`s'`j''))) ;

local xb`s'`j' _b[cut`s':_cons] - (_b[east]*`measta3140' + _b[a3140]*1 + _b[a4150]*0 + _b[a5160]*0 +  
_b[a6170]*0 + _b[a71]*0 + _b[ya1630]*0 + _b[ya3140]* ln(`i') + _b[ya4150]*0 + _b[ya5160]*0 + _b[ya6170]*0 + _b[ya71]*0 + 
_b[yrsedu]*`myrsedua3140' + _b[unemp]*`munempa3140' + _b[overtime]*`movertimea3140' + _b[wdisable]*`mwdisablea3140' + 
_b[separate]*`mseparatea3140' + _b[single]*`msinglea3140' + _b[hhsize]*`mhhsizea3140' + 
_b[y1984]*`my1984a3140' + _b[y1985]*`my1985a3140' + _b[y1986]*`my1986a3140' + 
_b[y1987]*`my1987a3140' + _b[y1988]*`my1988a3140' + _b[y1989]*`my1989a3140' + _b[y1990]*`my1990a3140' + 
_b[y1991]*`my1991a3140' + _b[y1992]*`my1992a3140' + _b[y1993]*`my1993a3140' + 
_b[y1994]*`my1994a3140' + _b[y1995]*`my1995a3140' + _b[y1996]*`my1996a3140' + _b[y1997]*`my1997a3140' +
_b[y1998]*`my1998a3140' + _b[y1999]*`my1999a3140' + 
_b[y2000]*`my2000a3140' + _b[y2001]*`my2001a3140' + _b[y2003]*`my2003a3140' 
+ _b[y2004]*`my2004a3140' + _b[y2005]*`my2005a3140' ) ;

  
mat prob_a3140 [`j',1] = 1 - (exp(`xb`s'`j'')/(1+exp(`xb`s'`j''))) ;


local xb`s'`j' _b[cut`s':_cons]-(_b[east]*`measta4150' + _b[a3140]*0 + _b[a4150]*1 + _b[a5160]*0 +  
_b[a6170]*0 + _b[a71]*0 + _b[ya1630]*0 + _b[ya3140]*0 + _b[ya4150]*ln(`i') + _b[ya5160]*0 + _b[ya6170]*0 + _b[ya71]*0 + 
_b[yrsedu]*`myrsedua4150' + _b[unemp]*`munempa4150' + _b[overtime]*`movertimea4150' + _b[wdisable]*`mwdisablea4150' + 
_b[separate]*`mseparatea4150' + _b[single]*`msinglea4150' + _b[hhsize]*`mhhsizea4150' + 
_b[y1984]*`my1984a4150' + _b[y1985]*`my1985a4150' + _b[y1986]*`my1986a4150' + 
_b[y1987]*`my1987a4150' + _b[y1988]*`my1988a4150' + _b[y1989]*`my1989a4150' + _b[y1990]*`my1990a4150' + 
_b[y1991]*`my1991a4150' + _b[y1992]*`my1992a4150' + _b[y1993]*`my1993a4150' + 
_b[y1994]*`my1994a4150' + _b[y1995]*`my1995a4150' + _b[y1996]*`my1996a4150' + _b[y1997]*`my1997a4150' +
_b[y1998]*`my1998a4150' + _b[y1999]*`my1999a4150' + 
_b[y2000]*`my2000a4150' + _b[y2001]*`my2001a4150' + _b[y2003]*`my2003a4150' 
+ _b[y2004]*`my2004a4150' + _b[y2005]*`my2005a4150' ) ;


mat prob_a4150[`j',1] = 1 - (exp(`xb`s'`j'')/(1+exp(`xb`s'`j''))) ;

local xb`s'`j' _b[cut`s':_cons]-(_b[east]*`measta5160' + _b[a3140]*0 + _b[a4150]*0 + _b[a5160]*1 +  
_b[a6170]*0 + _b[a71]*0 + _b[ya1630]*0 + _b[ya3140]*0 + _b[ya4150]*0 + _b[ya5160]*ln(`i') + _b[ya6170]*0 + _b[ya71]*0 + 
_b[yrsedu]*`myrsedua5160' + _b[unemp]*`munempa5160' + _b[overtime]*`movertimea5160' + _b[wdisable]*`mwdisablea5160' + 
_b[separate]*`mseparatea5160' + _b[single]*`msinglea5160' + _b[hhsize]*`mhhsizea5160' + 
_b[y1984]*`my1984a5160' + _b[y1985]*`my1985a5160' + _b[y1986]*`my1986a5160' + 
_b[y1987]*`my1987a5160' + _b[y1988]*`my1988a5160' + _b[y1989]*`my1989a5160' + _b[y1990]*`my1990a5160' + 
_b[y1991]*`my1991a5160' + _b[y1992]*`my1992a5160' + _b[y1993]*`my1993a5160' + 
_b[y1994]*`my1994a5160' + _b[y1995]*`my1995a5160' + _b[y1996]*`my1996a5160' + _b[y1997]*`my1997a5160' +
_b[y1998]*`my1998a5160' + _b[y1999]*`my1999a5160' + 
_b[y2000]*`my2000a5160' + _b[y2001]*`my2001a5160' + _b[y2003]*`my2003a5160' 
+ _b[y2004]*`my2004a5160' + _b[y2005]*`my2005a5160' ) ;

mat prob_a5160[`j',1] = 1 - (exp(`xb`s'`j'')/(1+exp(`xb`s'`j''))) ;

local xb`s'`j' _b[cut`s':_cons]-(_b[east]*`measta6170' + _b[a3140]*0 + _b[a4150]*0 + _b[a5160]*0 +  
_b[a6170]*1 + _b[a71]*0 + _b[ya1630]*0 + _b[ya3140]*0 + _b[ya4150]*0 + _b[ya5160]*0 + _b[ya6170]*ln(`i') + _b[ya71]*0 + 
_b[yrsedu]*`myrsedua6170' + _b[unemp]*`munempa6170' + _b[overtime]*`movertimea6170' + _b[wdisable]*`mwdisablea6170' + 
_b[separate]*`mseparatea6170' + _b[single]*`msinglea6170' + _b[hhsize]*`mhhsizea6170' + 
_b[y1984]*`my1984a6170' + _b[y1985]*`my1985a6170' + _b[y1986]*`my1986a6170' + 
_b[y1987]*`my1987a6170' + _b[y1988]*`my1988a6170' + _b[y1989]*`my1989a6170' + _b[y1990]*`my1990a6170' + 
_b[y1991]*`my1991a6170' + _b[y1992]*`my1992a6170' + _b[y1993]*`my1993a6170' + 
_b[y1994]*`my1994a6170' + _b[y1995]*`my1995a6170' + _b[y1996]*`my1996a6170' + _b[y1997]*`my1997a6170' +
_b[y1998]*`my1998a6170' + _b[y1999]*`my1999a6170' + 
_b[y2000]*`my2000a6170' + _b[y2001]*`my2001a6170' + _b[y2003]*`my2003a6170' + _b[y2004]*`my2004a6170' 
+ _b[y2005]*`my2005a6170' ) ;

mat prob_a6170[`j',1] = 1 - (exp(`xb`s'`j'')/(1+exp(`xb`s'`j''))) ;

local xb`s'`j' _b[cut`s':_cons]-(_b[east]*`measta71' + _b[a3140]*0 + _b[a4150]*0 + _b[a5160]*0 +  
_b[a6170]*0 + _b[a71]*1 + _b[ya1630]*0 + _b[ya3140]*0 + _b[ya4150]*0 + _b[ya5160]*0 + _b[ya6170]*0 + _b[ya71]*ln(`i') + 
_b[yrsedu]*`myrsedua71' + _b[unemp]*`munempa71' + _b[overtime]*`movertimea71' +_b[wdisable]*`mwdisablea71' + 
_b[separate]*`mseparatea71' + _b[single]*`msinglea71' + _b[hhsize]*`mhhsizea71' + 
_b[y1984]*`my1984a71' + _b[y1985]*`my1985a71' + _b[y1986]*`my1986a71' + 
_b[y1987]*`my1987a71' + _b[y1988]*`my1988a71' + _b[y1989]*`my1989a71' + _b[y1990]*`my1990a71' + 
_b[y1991]*`my1991a71' + _b[y1992]*`my1992a71' + _b[y1993]*`my1993a71' + 
_b[y1994]*`my1994a71' + _b[y1995]*`my1995a71' + _b[y1996]*`my1996a71' + _b[y1997]*`my1997a71' +
_b[y1998]*`my1998a71' + _b[y1999]*`my1999a71' + 
_b[y2000]*`my2000a71' + _b[y2001]*`my2001a71' + _b[y2003]*`my2003a71' + _b[y2004]*`my2004a71' + _b[y2005]*`my2005a71') ;

mat prob_a71[`j',1] = 1 - (exp(`xb`s'`j'')/(1+exp(`xb`s'`j''))) ;



local j = `j' + 1 ;	
} ;

svmat inc, name(income) ; 
svmat prob_a1630 , name(proba1630) ;
svmat prob_a3140, name(proba3140) ;
svmat prob_a4150, name(proba4150) ;
svmat prob_a5160, name(proba5160) ;
svmat prob_a6170, name(proba6170) ;
svmat prob_a71, name(proba71) ;


if `s' < 4 { ;
line proba16301 income1, lwidth(medthick) lcolor(red) pstyle(p2)  || 
line proba31401 income1, lwidth(medthick) lcolor(blue) pstyle(p3)  || 
line proba41501 income1, lwidth(medthick) lcolor(lime) pstyle(p4) || 
line proba51601 income1, lwidth(medthick) lcolor(pink) pstyle(p5) ||  
line proba61701 income1, lwidth(medthick) lcolor(gold) pstyle(p6) ||  
line proba711 income1, lwidth(medthick) lcolor(dkgreen) pstyle(p8) ||, 
plotregion(style(none))
ytitle("Pr(SWH > `s')") xtitle("Monthly Income (in Euro)") 
ylabel(,grid)
xlabel(500(500)5500) 
legend(cols(3) region(lstyle(none)) 
label(1 "16 to 30") label(2 "31 to 40") label(3 "41 to 50") 
label(4 "51 to 60") label(5 "61 to 70") label(6 "71 and older")) ;

graph export "SWH_OLOGIT_pr`s'_f.eps", as(eps) preview(on) replace ;

} ;


else { ;
line proba16301 income1, lwidth(medthick) lcolor(red) pstyle(p2)  || 
line proba31401 income1, lwidth(medthick) lcolor(blue) pstyle(p3)  || 
line proba41501 income1, lwidth(medthick) lcolor(lime) pstyle(p4) || 
line proba51601 income1, lwidth(medthick) lcolor(pink) pstyle(p5) ||  
line proba61701 income1, lwidth(medthick) lcolor(gold) pstyle(p6) ||  
line proba711 income1, lwidth(medthick) lcolor(dkgreen) pstyle(p8) ||, 
plotregion(style(none))
ytitle("Pr(SWH = 5)") xtitle("Monthly Income (in Euro)") 
ylabel(,grid)
xlabel(500(500)5500) 
legend(cols(3) region(lstyle(none)) 
label(1 "16 to 30") label(2 "31 to 40") label(3 "41 to 50") 
label(4 "51 to 60") label(5 "61 to 70") label(6 "71 and older")) ;

graph export "SWH_OLOGIT_pr`s'_f.eps", as(eps) preview(on) replace ;

} ;


drop income1 proba16301 proba31401 proba41501 proba51601 proba61701 proba711 ;

mat min`s' = J(6,1,0) ;
mat max`s' = J(6,1,0) ;

local i = 1 ;
while `i' < 7 {;
mat min`s'[`i',1] = meff`s'[`i',1] - 1.96*seeff`s'[`i',1] ;
mat max`s'[`i',1] = meff`s'[`i',1] + 1.96*seeff`s'[`i',1] ;

local i = `i' + 1 ;
} ;


svmat double meff`s', name(me`s') ;
svmat double min`s', name(min`s') ;
svmat double max`s', name(max`s') ;


local s = `s' + 1 ;
local j = 1 ;
} ;

keep me11 me21 me31 me41 min11 min21 min31 min41 max11 max21 max31 max41 ;

drop if me11==. ;
drop if me21==. ;
drop if me31==. ;
drop if me41==. ;


save "mepol_f.dta", replace ;
  
#delimit ;
use mepol_f.dta, clear ;
keep me11 min11 max11 ;
save "mepol1_f.dta", replace ;

use "mepol_f.dta", clear ;
keep me21 min21 max21 ;
save "mepol2_f.dta", replace ;

use "mepol_f.dta", clear ;
keep me31 min31 max31 ;
save "mepol3_f.dta", replace ;

use "mepol_f.dta", clear ;
keep me41 min41 max41 ;
save "mepol4_f.dta", replace ;

log close ;