************************************************************************************************************************************** 
************************Self-Assessed Health and Socio-Economic Status Using the GSOEP************************************************
***************************Project with Andrew Jones and Nigel Rice - 18 March 2006*************************************************** 
***************************"C: \Documents and Settings\Eigene Dateien\sah_ses\dofile_jrs0306.do"************************************** 
************************************************************************************************************************************** 


clear 
set trace off 
set more off 
set mem 500m 
set matsize 2200 

capture log close 

cd "C:\Documents and Settings\sschurer\My Documents\PhD Thesis Stefanie Schurer\SAH and SES Panel Methods\JAE Changes" 

log using summarystats, replace 
program drop _all 

use "GSOEP (1984-2005) Workdata Jones and Schurer", clear 


****************   Set the style of the graphs   ******************** 

set scheme s1manual 



**************************************************************************************************************** 
******                                          Set Local Macros                                            **** 
**************************************************************************************************************** 

#delimit ;

local depvars "swh" ;
local createswh "one two three four five" ;
local createwah "lot little no" ;
local createswhealth "swhezero swheone swhetwo swhethree swhefour swhefive swhesix swheseven 
swheeight swhenine swheten" ;
local listsah "sahvego sahgood sahsat sahpoor sahbad" ;
local listswh "swhone swhtwo swhthree swhfour swhfive" ;
local listwah "wahlot wahlittle wahno" ;
local listage "a1630 a3140 a4150 a5160 a6170 a71" ;
local listage2 "all a1630 a3140 a4150 a5160 a6170 a71" ;
local statvars1 "male female a1630 a3140 a4150 a5160 a6170 a71 east west immig" ;


global statvars2 "sah swhealth swh swhn1 wah age  
a1630 a3140 a4150 a5160 a6170 a71 
income minc
y2a1630 y2a3140  y2a4150 y2a5160 y2a6170 y2a71
unemp workhrs 
secondary intermed upper uni 
married single separate hhsize chilhh east west immig wdisable yrsip" ;

************************************************************ ;
*** Descriptive Statistics ********************************* ;
************************************************************ ;


#delimit ;
sum   $statvars2 if male == 1 ;
sutex $statvars2, labels  minmax file(summarytablemale.tex) replace ;

sum  $statvars2 if female == 1 ;
sutex $statvars2, labels minmax file(summarytablemale.tex) replace ;

 
   

*************************************************************************************** ;
***					Graphics								*** ;
*************************************************************************************** ;

cd "C:\Documents and Settings\sschurer\My Documents\PhD Thesis Stefanie Schurer\Masterfile" ;


****   SAH and SWH and WAH Histograms 	**** ;

local i = 1 ;
foreach var in `createswh'  { ;
gen swh`var' = 0 ;
replace swh`var' = 1 if swh == `i' ;
local i = `i' + 1 ;
} ;

local i = 1 ;
foreach var in `createwah'  { ;
gen wah`var' = 0 ;
replace wah`var' = 1 if wah == `i' ;
local i = `i' + 1 ;
} ;

local i = 0 ;
foreach var in `createswhealth'  { ;
gen `var' = 0 ;
replace `var' = 1 if swhealth == `i' ;
label var `var' "SWH `i'" ;
local i = `i' + 1 ;
} ;

#delimit :
foreach var0 of varlist male female { ;
histogram swhealth if `var0' == 1 & income > 500 & immig == 0, discrete 
ylabel(,grid)
xlabel(0(1)10);
graph export swhealthdbn`var0'.eps, 
as(eps) preview(on) replace ;
} ;

recode sah 5=1 4=2 2=4 1=5 ;

#delimit ;
foreach var0 of varlist male female { ;
histogram sah if `var0' == 1 & income > 500 & immig == 0, discrete 
ylabel(,grid)
xlabel(1(1)5);
graph export sahdbn`var0'.eps, 
as(eps) preview(on) replace ;
} ;


label variable sahvego "SAH - very good" ;
label variable sahgood "SAH - good" ;
label variable sahsat "SAH - satisfactory" ; 
label variable sahpoor "SAH - poor" ;
label variable sahbad "SAH - bad" ;
  
label variable swhone "1" ;
label variable swhtwo "2" ;
label variable swhthree "3" ;
label variable swhfour "4" ;
label variable swhfive "5" ;
 

label variable wahlot "WAH - worry a lot" ;
label variable wahlittle "WAH - worry a little" ; 
label variable wahno "WAH - no worries" ;
  

*****   By Income Quintiles ***** ;


foreach var1 of varlist `depvars' { ;
foreach var2 of varlist male female { ;
sort persnr year ;
xtile incq5`var2' = exp(lequinc1) if `var2' == 1 & income > 500 & immig == 0, n(5) ;
summ incq5`var2' ;
sort incq5`var2' ;
graph bar `list`var1'' 
if `var2' == 1, over(incq5`var2') 
plotregion(style(none))
legend(cols(3) region(lstyle(none)) label(1 "SWH 1") label(2 "SWH 2")
label(3 "SWH 3") label(4 "SWH 4") label(5 "SWH 5") ) ;
graph export swhincome`var2'.eps, 
as(eps) preview(on) replace ;
drop incq5`var2' ;
} ;
} ;




*****  By Educational Status  ****** ;

gen edumax = . ;
recode edumax . = 1 if secondary == 1 ;
recode edumax . = 2 if intermed == 1 ;
recode edumax . = 3 if upper == 1 ;
recode edumax . = 4 if uni == 1 ;
label define edlab 1 "9 or less " , add ;
label define edlab 2 "9 or 10" , add ;
label define edlab 3 "10 to 12" , add ;
label define edlab 4 "uni", add ;
label list edlab ;
label values edumax edlab ;
table edumax ;
sort edumax ;

foreach var1 of varlist `depvars' { ;
foreach var2 of varlist male female { ;
sort edumax ;
graph bar `list`var1'' 
if `var2' == 1 & income > 500 & immig == 0, over(edumax) 
plotregion(style(none))
legend(cols(3) region(lstyle(none)) label(1 "SWH 1") label(2 "SWH 2")
label(3 "SWH 3") label(4 "SWH 4") label(5 "SWH 5")) ;
graph export swhedu`var2'.eps, 
as(eps) preview(on) replace ;
} ;
} ;


*****    By Age Group    ***** ;



gen healthtab = 0 ;
local i = 1 ;
foreach var of varlist `listage' { ;
  replace healthtab = `i' if `var'==1 ;
  label define agelab `i' "`var'", add ;
  local i = `i' + 1 ;
  } ;


label list agelab ;
label values healthtab agelab ;

foreach var1 of varlist `depvars' { ;
foreach var2 of varlist male female { ;
sort healthtab ;
graph bar `list`var1'' 
if `var2' == 1 & healthtab != 0 & income > 500 & immig == 0, over(healthtab) 
plotregion(style(none))
legend(cols(3) region(lstyle(none)) label(1 "SWH 1") label(2 "SWH 2")
label(3 "SWH 3") label(4 "SWH 4") label(5 "SWH 5")) ;
graph export swhage`var2'.eps, 
as(eps) preview(on) replace ;
} ;
} ;


log close ;


